# EZML

EZ ML or Easy ML , is a ready to use collection of functions and classes frequently used in machine learning projects and kaggle competitions .

## Important Note 

This project is still in beta , docstrings exist inside the lib but no official documentation has been created yet .

Any contribution is welcome as long as it fits the spirit of the package.

## Getting Started

To start kicking ass you just need to install the library

```
pip install ezml
```

## Authors

* **Ghazi Ben Dahmen** - *Initial work* - [GhaziBenDahmen](https://github.com/GhaziBenDahmen)   

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details
